logError function
Logs the given value to the console as error (red color)
Implementation
void logError(String value) => stdout.writeln('\x1B[31m$value\x1B[0m');
Logs the given value to the console as error (red color)
void logError(String value) => stdout.writeln('\x1B[31m$value\x1B[0m');