helpers/example_generated_file library
Classes
- FlConf
- This class is generated using flconf command line tools. It helps to access the values provided in the configuration files.
Enums
- Config
- This enum is generated from the files in flconf directory, so it represents all the available configurations for this app.
Extensions
- ConfigExtension on Config
- An extension to parse enum value from string